library(tidyverse)
library(ggpattern)
library(ggstream)
library(ggsci)
library(scales)
library(ggrepel)
library(ggradar)

library(raster)
library(broom)

c25 <- c(
  "dodgerblue2", "#E31A1C", # red
  "green4",
  "#6A3D9A", # purple
  "#FF7F00", # orange
  "black", "gold1",
  "skyblue2", "#FB9A99", # lt pink
  "palegreen2",
  "#CAB2D6", # lt purple
  "#FDBF6F", # lt orange
  "gray70", "khaki2",
  "maroon", "orchid1", "deeppink1", "blue1", "steelblue4",
  "darkturquoise", "green1", "yellow4", "yellow3",
  "darkorange4", "brown"
)

height <- 5
width <- height*1.5

d.clean <- read.csv('contracts.cleaned.csv')

d.clean$contract_date <- as.Date(d.clean$contract_date)
d.clean$contract_period_start <- as.Date(d.clean$contract_period_start)
d.clean$economic_object_code <- as.factor(d.clean$economic_object_code)
d.clean$commodity_type <- as.factor(d.clean$commodity_type)
d.clean$commodity_code <- as.factor(d.clean$commodity_code)
d.clean$country_of_vendor <- as.factor(d.clean$country_of_vendor)
d.clean$solicitation_procedure <- as.factor(d.clean$solicitation_procedure)
d.clean$limited_tendering_reason <- as.factor(d.clean$limited_tendering_reason)
d.clean$trade_agreement_exceptions <- as.factor(d.clean$trade_agreement_exceptions)
d.clean$award_criteria <- as.factor(d.clean$award_criteria)

d.clean <- d.clean %>% mutate(vendor_province = case_when(str_starts(vendor_postal_code, 'A') ~ 'NL',
                                               str_starts(vendor_postal_code, 'B') ~ 'NS',
                                               str_starts(vendor_postal_code, 'C') ~ 'PE',
                                               str_starts(vendor_postal_code, 'E') ~ 'NB', 
                                               str_starts(vendor_postal_code, 'G|J') ~ 'QC',
                                               str_starts(vendor_postal_code, 'L|M|N|K|P') ~ 'ON',
                                               str_starts(vendor_postal_code, 'R') ~ 'MB',
                                               str_starts(vendor_postal_code, 'S') ~ 'SK',
                                               str_starts(vendor_postal_code, 'T') ~ 'AB',
                                               str_starts(vendor_postal_code, 'V') ~ 'BC',
                                               str_starts(vendor_postal_code, 'X') ~ 'NT',
                                               str_starts(vendor_postal_code, 'Y') ~ 'YK',
                                               TRUE ~ 'UNKWN'))

d.clean$vendor_province <- as.factor(d.clean$vendor_province)

# Density plot, one variable => counts
mean_v <- d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>% 
   pivot_longer(c(original_value, contract_value), names_to="value_type", values_to="value") %>% 
   summarize(mean_v = mean(value), median_v = median(value), lower95=quantile(value, .025), upper95=quantile(value, .975), maxdensity = max(density(value)$y))

d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>% 
   pivot_longer(c(original_value, contract_value), names_to="value_type", values_to="value") %>% 
   ggplot(aes(value)) + 
     geom_density(kernel='gaussian', n=4096, fill='lightblue') + 
     scale_x_continuous(labels=scales::comma) +
     scale_y_continuous(labels=scales::comma) + 
     # scale_fill_brewer(palette="Dark2") +
     labs(x = 'Canadian Dollars', y = 'Proportion of Contracts', title='Density Plot -- Canadian Federal Procurement Contracts by Value', subtitle='Years 2017 to 2022, Above C$10,000', caption='Lower and Upper 95 percentile, median and mean') +
     coord_cartesian(xlim=c(0, 100000)) +
     geom_vline(data=mean_v, aes(xintercept=mean_v), linetype='dashed') +
     geom_vline(data=mean_v, aes(xintercept=median_v), linetype='dotdash') +
     geom_vline(data=mean_v, aes(xintercept=lower95), linetype='dotted') +
     geom_vline(data=mean_v, aes(xintercept=upper95), linetype='dotted') + 
     annotate('text', label = paste(' L95=\n ', round(mean_v$lower95), sep=''), x = mean_v$lower95, y = mean_v$maxdensity/2, size=3.5, hjust=0) +
     annotate('text', label = paste(' Med=\n ', round(mean_v$median_v), sep=''), x = mean_v$median_v, y = mean_v$maxdensity*3/4, size=3.5, hjust=0) +
     annotate('text', label = paste(' Mean=\n ', round(mean_v$mean_v), sep=''), x = mean_v$mean_v, y = mean_v$maxdensity*5/8, size=3.5, hjust=0) + 
     annotate('text', label = paste(' U95=\n ', round(mean_v$upper95), sep=''), x = mean_v$upper95, y = mean_v$maxdensity/2, size=3.5, hjust=0)

ggsave("density.png", height=height, width=width)
ggsave("density.pdf", height=height, width=width)

# Histogram plot, one variable => counts
mean_v <- d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>% 
   pivot_longer(c(original_value, contract_value), names_to="value_type", values_to="value") %>% 
   summarize(mean_v = mean(value), median_v = median(value), lower95=quantile(value, .025), upper95=quantile(value, .975), maxdensity = max(density(value)$y))

d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>% 
   pivot_longer(c(original_value, contract_value), names_to="value_type", values_to="value") %>% 
   ggplot(aes(value)) + 
     geom_histogram(aes(y=..density..), bins=50, fill='white', color='black', alpha=0.5) +
     geom_density(kernel='gaussian', n=4096, fill='lightblue', alpha=0.5) + 
     scale_x_continuous(labels=scales::comma) +
     scale_y_continuous(labels=scales::comma) + 
     # scale_fill_brewer(palette="Dark2") +
     labs(x = 'Canadian Dollars', y = 'Proportion of Contracts', title='Density Plot -- Canadian Federal Procurement Contracts by Value', subtitle='Years 2017 to 2022, Above C$10,000', caption='Lower and Upper 95 percentile, median and mean') +
     coord_cartesian(xlim=c(0, 100000)) +
     geom_vline(data=mean_v, aes(xintercept=mean_v), linetype='dashed') +
     geom_vline(data=mean_v, aes(xintercept=median_v), linetype='dotdash') +
     geom_vline(data=mean_v, aes(xintercept=lower95), linetype='dotted') +
     geom_vline(data=mean_v, aes(xintercept=upper95), linetype='dotted') +
     annotate('text', label = paste(' L95=\n ', round(mean_v$lower95), sep=''), x = mean_v$lower95, y = mean_v$maxdensity/2, size=3.5, hjust=0) +
     annotate('text', label = paste(' Med=\n ', round(mean_v$median_v), sep=''), x = mean_v$median_v, y = mean_v$maxdensity*3/4, size=3.5, hjust=0) +
     annotate('text', label = paste(' Mean=\n ', round(mean_v$mean_v), sep=''), x = mean_v$mean_v, y = mean_v$maxdensity*5/8, size=3.5, hjust=0) + 
     annotate('text', label = paste(' U95=\n ', round(mean_v$upper95), sep=''), x = mean_v$upper95, y = mean_v$maxdensity/2, size=3.5, hjust=0)
     # scale_fill_brewer(palette="Paired") +

ggsave("histogram.png", height=height, width=width)
ggsave("histogram.pdf", height=height, width=width)

# Area plot, two variables in one series
d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(commodity_type=case_when(commodity_type=='C' ~ 'Construction',
									commodity_type=='G' ~ 'Goods',
									commodity_type=='S' ~ 'Services')) %>%
   mutate(contract_quarter = floor_date(contract_date, 'week')) %>%								
   group_by(contract_quarter) %>%
   summarize(daily_value = sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(contract_quarter, daily_value)) + 
     geom_area(fill='purple') +
     scale_y_continuous(labels=scales::comma) +
     labs(x = 'Date', y = 'Weekly Total Contract Value', title='Weekly Canadian Federal Procurement Contract Values', subtitle='Year 2022, Above C$10,000')
ggsave("areaOneSeries.png", height=height, width=width)
ggsave("areaOneSeries.pdf", height=height, width=width)

# Area plot, two variables in three series
d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(commodity_type=case_when(commodity_type=='C' ~ 'Construction',
									commodity_type=='G' ~ 'Goods',
									commodity_type=='S' ~ 'Services')) %>%
   mutate(contract_quarter = floor_date(contract_date, 'week')) %>%								
   group_by(contract_date, commodity_type) %>%
   summarize(daily_value = sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(contract_date, daily_value, fill=reorder(commodity_type, -daily_value))) + 
     geom_area() +
     geom_stream(type='ridge', bw=0.2) +
     scale_fill_brewer(palette="Spectral") +
     scale_y_continuous(labels=scales::comma) +
     coord_cartesian(ylim=c(0,1000000)) + 
     labs(x = 'Date', y = 'Weekly Total Contract Value', fill='Commodity Type', title='Weekly Canadian Federal Procurement Contract Values', subtitle='Year 2022, Above C$10,000')
ggsave("areaThreeSeries.png", height=height, width=width)
ggsave("areaThreeSeries.pdf", height=height, width=width)

# Area plot, stacked to show proportion of total, smoothed
d.clean %>% 
   filter(original_value < quantile(original_value, .90)) %>% 
   filter(contract_value < quantile(contract_value, .90)) %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   filter(vendor_province != 'UNKWN') %>%
   mutate(commodity_type=case_when(commodity_type=='C' ~ 'Construction',
									commodity_type=='G' ~ 'Goods',
									commodity_type=='S' ~ 'Services')) %>%
   group_by(contract_date, commodity_type) %>%
   summarize(daily_value = sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(x=contract_date, y=daily_value, fill=reorder(commodity_type, daily_value))) + 
     geom_area(position="fill", alpha=0.5) +
     geom_stream(type = "proportional", bw=0.5, color='black') +
#      scale_fill_brewer(palette="Paired") +
	 scale_color_tron() +
	 scale_fill_tron() +
     scale_y_continuous(labels=scales::comma) +
     labs(x = 'Contract Date', y = 'Proportion of Total Contract Value', fill='Commodity Type', title='Daily Canadian Federal Procurement Contract Values', subtitle='Year 2022, Above C$10,000')
ggsave("areaThreeSeriesStacked.png", height=height, width=width)
ggsave("areaThreeSeriesStacked.pdf", height=height, width=width)

# Column Plot
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   mutate(year=substr(contract_date, 1, 4)) %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   group_by(solicitation_procedure, year) %>%
   summarize(totalvalue = sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(year, totalvalue, fill=solicitation_procedure)) +
      geom_col() +
      scale_fill_brewer(palette="Paired") +
      scale_fill_discrete(labels=c("Advance Contract Award Notice", "Open Bidding", "Selective Tendering", "Traditional", "Non-Competitive", "Unknown")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Contract Date', y = 'Annual Total Contract Value', fill='Solicitation Procedure', title='Canadian Federal Procurement Contract Values', subtitle='2017 to 2022, Contracts above C$10,000')
ggsave("columns.png", height=height, width=width)
ggsave("columns.pdf", height=height, width=width)


# Column Plot with Patterns
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   mutate(year=substr(contract_date, 1, 4)) %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   group_by(solicitation_procedure, year) %>%
   summarize(totalvalue = sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(year, totalvalue, pattern_angle=solicitation_procedure)) +
      geom_col_pattern( aes(pattern_type=solicitation_procedure),
						pattern_fill='white', 
						pattern='polygon_tiling',
						pattern_scale=0.5,
						pattern_key_scale_factor=0.4) +
      scale_fill_brewer(palette="Paired") +
      scale_pattern_type_manual(values = c('hexagonal', 'rhombille', 'pythagorean', 'truncated_square', 'rhombitrihexagonal', 'truncated_trihexagonal'), labels=c("Advance Contract\nAward Notice", "Open Bidding", "Selective Tendering", "Traditional", "Non-Competitive", "Unknown")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Contract Date', y = 'Annual Total Contract Value', pattern_type='Solicitation Procedure', title='Canadian Federal Procurement Contract Values', subtitle='2017 to 2022, Contracts above C$10,000') +
      guides(pattern_angle=FALSE, pattern_type=guide_legend(nrow=1)) + 
      theme(legend.key.size=unit(1, 'cm'), legend.position='bottom') +
      guides(pattern_type=guide_legend(nrow=2,byrow=TRUE, legend.position='bottom', keyheight=unit(1, 'cm'), keywidth=unit(1, 'cm')))
ggsave("columnsPatterns.png", height=height, width=width)
ggsave("columnsPatterns.pdf", height=height, width=width)


# Box Plot
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   ggplot(aes(vendor_province, contract_value, fill=region)) +
      geom_boxplot() +
      scale_fill_brewer(palette="Paired") +
      # scale_fill_discrete(labels=c("Advance Contract Award Notice", "Open Bidding", "Selective Tendering", "Traditional", "Non-Competitive", "Unknown")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Province of Vendor', y = 'Contract Value', fill='Region', title='Canadian Federal Procurement Contract Values', subtitle='2017 to 2022, Contracts above C$10,000')
ggsave("box.png", height=height, width=width)
ggsave("box.pdf", height=height, width=width)

# violin Plot
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   ggplot(aes(vendor_province, contract_value, fill=region)) +
      geom_violin() +
      scale_fill_brewer(palette="Paired") +
      # scale_fill_discrete(labels=c("Advance Contract Award Notice", "Open Bidding", "Selective Tendering", "Traditional", "Non-Competitive", "Unknown")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Province of Vendor', y = 'Contract Value', fill='Region', title='Canadian Federal Procurement Contract Values', subtitle='2017 to 2022, Contracts above C$10,000') +
      # geom_boxplot(color='black', fill=NA, alpha=0.8)
      geom_jitter(width=0.15, color='darkgrey', size=1, fill=NA, alpha=0.5) + 
      theme(legend.position='top', 
				legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill='lightgrey'),
				legend.key.size=unit(1, 'cm')) 
ggsave("violinJitter.png", height=height, width=width)
ggsave("violinJitter.pdf", height=height, width=width)

# dotplot
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   filter(region=='Atlantic') %>%
   ggplot(aes(x=vendor_province, y=contract_value, color=vendor_province, fill=vendor_province)) +
      geom_dotplot(binaxis='y', stackdir='center', dotsize=1) +
      scale_fill_brewer(palette="Paired") +
      scale_y_continuous(labels=scales::comma) + 
	  guides(color=FALSE) +
      labs(x = 'Province of Vendor', y = 'Contract Value', fill='Province', color=NULL, title='Canadian Federal Procurement Contract Values for Atlantic Canada', subtitle='2017 to 2022, Contracts above C$10,000') +
      theme(legend.position='top', 
				legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill='lightgrey'),
				legend.key.size=unit(1, 'cm')) +
	  geom_violin(color='black', fill=NA)

ggsave("dotplot.png", height=height, width=width)
ggsave("dotplot.pdf", height=height, width=width)

d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   filter(region=='Atlantic') %>%
   ggplot(aes(x=vendor_province, y=contract_value, color=vendor_province, fill=vendor_province)) +
      geom_dotplot(binaxis='y', stackdir='center', dotsize=1) +
      scale_fill_brewer(palette="Paired") +
      scale_y_continuous(labels=scales::comma) + 
	  guides(color=FALSE) +
      labs(x = 'Province of Vendor', y = 'Contract Value', fill='Province', color=NULL, title='Canadian Federal Procurement Contract Values for Atlantic Canada', subtitle='2017 to 2022, Contracts above C$10,000') +
      theme(legend.position='none') +
	  geom_violin(color='black', fill=NA) + 
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), size=2, color='red', geom="pointrange")

ggsave("dotplotsummaries.png", height=height, width=width)
ggsave("dotplotsummaries.pdf", height=height, width=width)

# Counts
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
#   group_by(region, commodity_type) %>%
#   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
#   ungroup() %>%
   ggplot(aes(region, commodity_type)) +
      geom_count(aes(color=region))+
      scale_size_area(max_size=10, n.breaks=6) + 
      scale_color_brewer(palette="Paired") +
#      scale_y_continuous(labels=scales::comma) + 
	  scale_y_discrete(labels=c('Construction', 'Goods', 'Services')) + 
	  guides(color=FALSE) +
      labs(x = 'Region', y = 'Commodity Type',  n='Count', title='Canadian Federal Procurement Contract Counts', subtitle='2017 to 2022, Contracts above C$10,000') +
     theme(		legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill=NA),
				legend.key.size=unit(1, 'cm'))
#      theme(legend.position='none') +

ggsave("count.png", height=height, width=width)
ggsave("count.pdf", height=height, width=width)

# Jitter over Discrete
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
#   group_by(region, commodity_type) %>%
#   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
#   ungroup() %>%
   ggplot(aes(region, commodity_type)) +
      geom_jitter(aes(color=paste(region, commodity_type))) +
      scale_color_manual(values=c25) +
#      scale_y_continuous(labels=scales::comma) + 
	  scale_y_discrete(labels=c('Construction', 'Goods', 'Services')) + 
	  guides(color=FALSE) +
      labs(x = 'Region', y = 'Commodity Type',  n='Count', title='Canadian Federal Procurement Contracts', subtitle='2017 to 2022, Contracts above C$10,000') +
     theme(		legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill=NA),
				legend.key.size=unit(1, 'cm'))
#      theme(legend.position='none') +

ggsave("jitterdiscrete.png", height=height, width=width)
ggsave("jitterdiscrete.pdf", height=height, width=width)

# Counts
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2017-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   mutate(contract_quarter = floor_date(contract_date, 'quarter')) %>%
   group_by(contract_quarter, commodity_type) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(contract_quarter, totalvalue, color=commodity_type, size=totalcount)) +
      geom_point(alpha=0.8) +
      scale_size_continuous(range=c(0, 20)) +
      scale_color_tron(labels=c('Construction', 'Goods', 'Services')) +
      scale_y_continuous(labels=scales::comma) + 
	  # guides(color=FALSE) +
	  guides(color=guide_legend(override.aes = list(size=15))) +
      labs(x = 'Quarter', y = 'Quarterly Total Contract Value',  color='Commodity Type', size='Contract Count', title='Quraterly Canadian Federal Procurement Contract Counts \& Values', subtitle='2017 to 2022, Contracts above C$10,000')
      # theme(legend.key.size=unit(1, 'cm'))

ggsave("pointsSize.png", height=height, width=width)
ggsave("pointsSize.pdf", height=height, width=width)

# Lines and Points
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2021-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   mutate(contract_quarter = floor_date(contract_date, 'month')) %>%
   group_by(contract_quarter, commodity_type) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(contract_quarter, totalvalue, color=commodity_type, shape=commodity_type, linetype=commodity_type)) +
	  geom_line(size=1) + 
	  geom_point(size=4) + 
      scale_color_tron(labels=c('Construction', 'Goods', 'Services')) +
      scale_linetype(labels=c('Construction', 'Goods', 'Services')) +
      scale_shape(labels=c('Construction', 'Goods', 'Services')) +
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Monthly Total Contract Value',  color='Commodity Type', shape='Commodity Type', linetype='Commodity Type', title='Monthly Canadian Federal Procurement Contract Values', subtitle='2021 to 2022, Contracts above C$10,000') +
      theme(legend.key.size=unit(1.5, 'cm'))

ggsave("linesPoints.png", height=height, width=width)
ggsave("linesPoints.pdf", height=height, width=width)


# Steps
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2021-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NS', 'PE', 'NB') ~ 'Atlantic',
								vendor_province %in% c('YK', 'NT') ~ 'Northern',
								vendor_province %in% c('AB', 'SK', 'MB') ~ 'Prairies',
								vendor_province %in% c('QC', 'ON') ~ 'Central',
								vendor_province %in% c('BC') ~ 'Western')) %>%
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   mutate(contract_quarter = floor_date(contract_date, 'month')) %>%
   group_by(contract_quarter, commodity_type) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(contract_quarter, totalvalue, color=commodity_type)) +
	  geom_step(size=1) + 
	  # geom_point(size=4) + 
      scale_color_jco(labels=c('Construction', 'Goods', 'Services')) +
      scale_linetype(labels=c('Construction', 'Goods', 'Services')) +
      # scale_shape(labels=c('Construction', 'Goods', 'Services')) +
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Monthly Total Contract Value',  color='Commodity Type', shape='Commodity Type', linetype='Commodity Type', title='Montlhy Canadian Federal Procurement Contract Values', subtitle='2021 to 2022, Contracts above C$10,000') +
      theme(legend.key.size=unit(1.5, 'cm'))

ggsave("steps.png", height=height, width=width)
ggsave("steps.pdf", height=height, width=width)

# Pie
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   group_by(vendor_province) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(x='', y=totalvalue, fill=vendor_province)) +
	  geom_bar(stat='identity', width=1) + 
	  coord_polar('y', direction=-1, start=0) +
	  geom_text(aes(label=ifelse(totalvalue > 1000000, round(totalvalue/1000000, digits=1), '')), color='lightgrey', position = position_stack(vjust=0.5)) +
	  # geom_point(size=4) + 
      # scale_color_jco() +
      scale_y_continuous(labels=NULL) + 
      scale_color_brewer(palette="Paired") +
      labs(x = '', y = '',  fill='Vendor Province', title='Canadian Federal Procurement Contract Values', subtitle='2022, Millions of C$, Contracts above C$10,000') +
      theme_void() +
      theme(legend.key.size=unit(1, 'cm'))

ggsave("pie.png", height=width, width=width)
ggsave("pie.pdf", height=width, width=width)

hsize <- 2
# Donut
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   group_by(vendor_province) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   ggplot(aes(x=hsize, y=totalvalue, fill=vendor_province)) +
	  geom_col() + 
	  coord_polar('y', direction=-1, start=0) +
	  xlim(c(0.2, hsize+0.5)) + 
	  geom_text(aes(label=ifelse(totalvalue > 1000000, round(totalvalue/1000000, digits=1), '')), color='lightgrey', position = position_stack(vjust=0.5)) +
	  # geom_point(size=4) + 
      # scale_color_jco() +
      # scale_y_continuous(labels=scales::comma) + 
      scale_color_brewer(palette="Paired") +
      labs(x = '', y = '',  fill='Vendor Province', title='Canadian Federal Procurement Contract Values', subtitle='2022, Millions of C$, Contracts above C$10,000') +
      theme_void() +
      theme(legend.key.size=unit(1, 'cm'))

ggsave("donut.png", height=width, width=width)
ggsave("donut.pdf", height=width, width=width)


# Radar
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2022-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(vendor_province = factor(vendor_province, levels=c('BC', 'AB', 'SK', 'MB', 'ON', 'QC', 'NB', 'NS', 'PE', 'NL', 'YK', 'NT'), ordered=TRUE)) %>%
   filter(vendor_province %in% c('NL', 'PE', 'NB', 'NS')) %>%
   group_by(vendor_province, commodity_type) %>%
   summarize(totalcount = n(), totalvalue=sum(contract_value)/1000000) %>%
   ungroup() %>%
   pivot_wider(names_from='commodity_type', values_from=totalvalue) %>%
   replace_na(list(C=0, G=0, S=0)) %>%
   select(vendor_province, 'C', 'G', 'S') %>%
   mutate_at(vars(-vendor_province), rescale) %>%
   relocate(vendor_province, .before=1) %>%
   ggradar(axis.labels=c('Construction', 'Goods', 'Services'), values.radar='') +
      scale_color_brewer(palette="Paired") +
      labs(x = '', y = '',  fill='Vendor Province', title='Canadian Federal Procurement Contract Values', subtitle='Atlantic Canada, 2022, Contracts above C$10,000') +
      theme(plot.title=element_text(size=18), plot.subtitle=element_text(size=14))
      
ggsave("radar.png", height=width, width=width)
ggsave("radar.pdf", height=width, width=width)


# Lines with Multiple Axes
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2021-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(region = case_when(vendor_province %in% c('NL', 'NB', 'NS', 'PE') ~ 'Atlantic',
							 TRUE ~ 'Rest')) %>%
   mutate(contract_quarter = floor_date(contract_date, 'month')) %>%
   group_by(contract_quarter, region) %>%
   summarize(totalvalue=sum(contract_value)) %>%
   ungroup() %>%
   pivot_wider(names_from='region', values_from='totalvalue') %>%
   mutate(Atlantic2 = 20*Atlantic) %>%
#   replace_na(list(Atlantic2=0)) %>%
   ggplot(aes(x=contract_quarter)) +
	  scale_color_manual(name='Region', values=c('Rest of Canada' = 'red', 'Atlantic' = 'blue')) +
	  geom_line(aes(y=Atlantic2, color='Atlantic'), size=1) + 
	  geom_line(aes(y=Rest, color='Rest of Canada'), size=1) +
      scale_y_continuous(labels=scales::comma, name="C$ Contract Value Rest of Canada", sec.axis=sec_axis(~./20, labels=scales::comma, name="C$ Contract Value Atlantic Canada")) + 
	  scale_x_date(date_breaks = "months" , date_labels = "%b-%y") +
      labs(x = 'Month', y = 'Total Contract Value', color='Region', title='Monthly Canadian Federal Procurement Contract Values by Region', subtitle='2021 to 2022, Contracts above C$10,000') +
      theme(legend.key.size=unit(1.5, 'cm'), axis.text.x = element_text(angle=45, hjust=1), axis.text.y.left = element_text(color='red'), axis.text.y.right = element_text(color='blue'), axis.title.y.left = element_text(color='red'), axis.title.y.right=element_text(color='blue'))

ggsave("linesTwoScales.png", height=height, width=width)
ggsave("linesTwoScales.pdf", height=height, width=width)

# Lines with Smooth
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2020-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(contract_week = floor_date(contract_date, 'month')) %>%
   filter(commodity_type=='C') %>%
   ggplot(aes(contract_week, contract_value)) +
	  geom_point(aes(color=commodity_type)) +
	  geom_smooth() +
	  guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Total Contract Value', color=NULL, title='Monthly Canadian Federal Procurement Contract Values (Construction)', subtitle='2020 to 2022, Contracts above C$10,000')

ggsave("linesSmooth.png", height=height, width=width)
ggsave("linesSmooth.pdf", height=height, width=width)

# Lines with Smooth and Point Range
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2020-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(contract_week = floor_date(contract_date, 'month')) %>%
   filter(commodity_type=='C') %>%
   ggplot(aes(contract_week, contract_value)) +
	  geom_smooth() +
	  geom_point() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), geom="pointrange") +
	  # geom_point(aes(color=commodity_type)) +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Total Contract Value', color=NULL, title='Monthly Canadian Federal Procurement Contract Values (Construction)', subtitle='2020 to 2022, Contracts above C$10,000')

ggsave("linesSmoothPointRange.png", height=height, width=width)
ggsave("linesSmoothPointRange.pdf", height=height, width=width)

# Lines with Smooth and ErrorBar
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2020-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(contract_week = floor_date(contract_date, 'month')) %>%
   filter(commodity_type=='C') %>%
   ggplot(aes(contract_week, contract_value)) +
	  geom_smooth() +
	  geom_point() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), geom="errorbar") +
	  # geom_point(aes(color=commodity_type)) +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Total Contract Value', color=NULL, title='Monthly Canadian Federal Procurement Contract Values (Construction)', subtitle='2020 to 2022, Contracts above C$10,000')

ggsave("linesSmoothErrorBar.png", height=height, width=width)
ggsave("linesSmoothErrorBar.pdf", height=height, width=width)


# Lines with Smooth and CrossBar
d.clean %>% 
   filter(original_value < quantile(original_value, .95)) %>% 
   filter(contract_value < quantile(contract_value, .95)) %>%
   filter(vendor_province != 'UNKWN') %>%
   filter(contract_date >= '2020-01-01') %>%
   filter(contract_date <= '2022-12-31') %>% 
   mutate(contract_week = floor_date(contract_date, 'month')) %>%
   filter(commodity_type=='C') %>%
   ggplot(aes(contract_week, contract_value)) +
	  geom_smooth() +
	  geom_point() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), geom="crossbar", width=10) +
	  # geom_point(aes(color=commodity_type)) +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=3)) +
      labs(x = 'Month', y = 'Total Contract Value', color=NULL, title='Monthly Canadian Federal Procurement Contract Values (Construction)', subtitle='2020 to 2022, Contracts above C$10,000')

ggsave("linesSmoothCrossBar.png", height=height, width=width)
ggsave("linesSmoothCrossBar.pdf", height=height, width=width)


# Mapping Data

# Alternative 1: Use raster to get the data directly from the GADM repo
#
canada.gadm <- getData("GADM",country="CAN",level=1)
canada.gadm.tidy <- tidy(canada.gadm)

d.gadm.id <- as.data.frame(
	d.clean %>% mutate(id = case_when(
		vendor_province == 'NL' ~ '9',
		vendor_province == 'PE' ~ '2',
		vendor_province == 'NS' ~ '11',
		vendor_province == 'NB' ~ '8',
		vendor_province == 'QC' ~ '3',
		vendor_province == 'ON' ~ '13',
		vendor_province == 'MB' ~ '7',
		vendor_province == 'SK' ~ '4',
		vendor_province == 'AB' ~ '1',
		vendor_province == 'BC' ~ '6',
		vendor_province == 'NT' ~ '10',
		vendor_province == 'YK' ~ '5',
		vendor_province == 'NU' ~ '12',
		TRUE ~ '-1')) %>%
	filter(vendor_province != 'UNKWN') %>%
	filter(contract_date >= '2020-01-01') %>%
	filter(contract_date <= '2022-12-31') %>% 
	group_by(id) %>% 
	summarize(totalvalue = sum(contract_value) %>%
	ungroup())

canada.gadm.data <- left_join(canada.gadm.tidy, d.gadm.id, by='id')

ggplot(canada.gadm.data, aes(x=long,y=lat,group=group))+
  geom_polygon(aes(fill=totalvalue), linewidth=0.1, color='black') +
  coord_map() +
  scale_fill_continuous(type='viridis', labels=scales::comma) + 
  guides(x='none', y='none') + 
  labs(x='Degrees Longitude', y='Degrees Latitude', fill='Total CAD', title='Canada Federal Procurement Contract Values', subtitle='2020 to 2022, Contracts above $10,000')

ggsave("contracts.GADM1.png", height=height, width=width)
ggsave("contracts.GADM1.pdf", height=height, width=width)


# Alternative 2: Use raster to load the shapefile data from a manual download of the GADM data
#
canada.gadm <- shapefile('gadm41_CAN_1.shp')
canada.gadm.tidy <- tidy(canada.gadm)

d.gadm.id <- as.data.frame(
	d.clean %>% mutate(id = case_when(
		vendor_province == 'NL' ~ '4',
		vendor_province == 'PE' ~ '9',
		vendor_province == 'NS' ~ '6',
		vendor_province == 'NB' ~ '3',
		vendor_province == 'QC' ~ '10',
		vendor_province == 'ON' ~ '8',
		vendor_province == 'MB' ~ '2',
		vendor_province == 'SK' ~ '11',
		vendor_province == 'AB' ~ '0',
		vendor_province == 'BC' ~ '1',
		vendor_province == 'NT' ~ '5',
		vendor_province == 'YK' ~ '12',
		vendor_province == 'NU' ~ '7',
		TRUE ~ '-1')) %>%
	filter(vendor_province != 'UNKWN') %>%
	filter(contract_date >= '2020-01-01') %>%
	filter(contract_date <= '2022-12-31') %>% 
	group_by(id) %>% 
	summarize(totalvalue = n()) %>%
	ungroup())

canada.gadm.data <- left_join(canada.gadm.tidy, d.gadm.id, by='id')

ggplot(canada.gadm.data, aes(x=long,y=lat,group=group))+
  geom_polygon(aes(fill=totalvalue), linewidth=0.1, color='black') +
  coord_map() +
  scale_fill_continuous(type='viridis', labels=scales::comma) + 
  guides(x="none", y="none") +
  labs(x='', y='', fill='Number of\nContracts', title='Canada Federal Procurement Contracts', subtitle='2020 to 2022, Contracts above $10,000') +
  theme(aspect.ratio=1)

ggsave("contracts.GADM2.png", height=height, width=width)
ggsave("contracts.GADM2.pdf", height=height, width=width)

# Alternative 3: Use raster to load the shapefile data from a download of the Statistics Canada data
#
canada.statscan <- shapefile('lpr_000b16a_e.shp')
canada.statscan.tidy <- tidy(canada.statscan)

d.statscan.id <- as.data.frame(
	d.clean %>% mutate(id = case_when(
		vendor_province == 'NL' ~ '0',
		vendor_province == 'PE' ~ '1',
		vendor_province == 'NS' ~ '2',
		vendor_province == 'NB' ~ '3',
		vendor_province == 'QC' ~ '4',
		vendor_province == 'ON' ~ '5',
		vendor_province == 'MB' ~ '6',
		vendor_province == 'SK' ~ '7',
		vendor_province == 'AB' ~ '8',
		vendor_province == 'BC' ~ '9',
		vendor_province == 'NT' ~ '11',
		vendor_province == 'YK' ~ '10',
		vendor_province == 'NU' ~ '12',
		TRUE ~ '-1')) %>%
	filter(vendor_province != 'UNKWN') %>%
	filter(contract_date >= '2020-01-01') %>%
	filter(contract_date <= '2022-12-31') %>% 
	group_by(id) %>% 
	summarize(totalvalue = sum(contract_value)) %>%
	ungroup())
	
canada.statscan.data <- left_join(canada.statscan.tidy, d.statscan.id, by='id')

ggplot() +
  geom_polygon(	data = canada.statscan.data, 
				aes(x = long, y = lat, group = group, fill = totalvalue),
				color = "black", 
				size = 0.1) +
  # scale_fill_continuous(type='viridis') + 
  scale_fill_continuous(type='viridis', labels=scales::comma) + 
  coord_map() + 
  guides(x=FALSE, y=FALSE) + 
  labs(x='', y='', fill='Total $C', title='Canada Federal Procurement Contract Values', subtitle='2020 to 2022, Contracts above $10,000')
  
ggsave("contracts.StatsCan.png", height=height, width=width)
ggsave("contracts.StatsCan.pdf", height=height, width=width)

# Colow swatches
library(colorspace)
library(jpeg)

pdf('viridis.plot.pdf', height=height, width=width)
swatchplot("Viridis Palette" = sequential_hcl(10, "Viridis"), cvd=c("deuteran", "protan", "tritan", "desaturate"))
dev.off()

pdf('sequential.pdf', height=3, width=10)
swatchplot("Sequential" = brewer_pal()(9))
dev.off()
pdf('diverging.pdf', height=3, width=10)
swatchplot("Diverging" = div_gradient_pal(low='red', high='blue', mid='white')(seq(0, 1, length.out=9)))
dev.off()
pdf('monochromatic.pdf', height=3, width=10)
swatchplot("Diverging" = grey_pal()(9))
dev.off()
pdf('brewer.paired.pdf', height=3, width=10)
swatchplot("Spectral" = brewer_pal(palette='Paired')(9))
dev.off()

pdf('brewer.paired.cvd.pdf', height=height, width=width)
swatchplot("Brewer Paired" = brewer_pal(palette='Paired')(9), cvd=c("deuteran", "protan", "tritan", "desaturate"))
dev.off()

# Colour Vision Deficiency Simulator
cvd_emulator('photo.jpg')
