import pandas as pd

from dash import Dash, html, dcc, callback, Output, Input
import dash_bootstrap_components as dbc
import plotly.express as px
import plotly.io as pio
pio.kaleido.scope.mathjax = None
pio.renderers.default = 'chromium'
pd.set_option('display.max_columns', None)

width = 800
aspect = 1.5

contractsData = pd.read_csv('/home/joerg/Teaching/BUSI4720_Dev/Visualization/contracts.cleaned.csv', low_memory=False)

contractsData['contract_date'] = pd.to_datetime(contractsData['contract_date'])
contractsData['contract_period_start'] = pd.to_datetime(contractsData['contract_period_start'])
contractsData['economic_object_code'] = contractsData['economic_object_code'].astype('category')
contractsData['commodity_type'] = contractsData['commodity_type'].astype('category')
contractsData['country_of_vendor'] = contractsData['country_of_vendor'].astype('category')
contractsData['solicitation_procedure'] = contractsData['solicitation_procedure'].astype('category')
contractsData['limited_tendering_reason'] = contractsData['limited_tendering_reason'].astype('category')
contractsData['trade_agreement_exceptions'] = contractsData['trade_agreement_exceptions'].astype('category')
contractsData['award_criteria'] = contractsData['award_criteria'].astype('category')

def prov_from_postal(row):
    if str(row['vendor_postal_code']).startswith('A'): return 'NL'
    if str(row['vendor_postal_code']).startswith('B'): return 'NS'
    if str(row['vendor_postal_code']).startswith('C'): return 'PE'
    if str(row['vendor_postal_code']).startswith('E'): return 'NB'
    if str(row['vendor_postal_code']).startswith('G'): return 'QC'
    if str(row['vendor_postal_code']).startswith('J'): return 'QC'
    if str(row['vendor_postal_code']).startswith('L'): return 'ON'
    if str(row['vendor_postal_code']).startswith('M'): return 'ON'
    if str(row['vendor_postal_code']).startswith('N'): return 'ON'
    if str(row['vendor_postal_code']).startswith('K'): return 'ON'
    if str(row['vendor_postal_code']).startswith('P'): return 'ON'
    if str(row['vendor_postal_code']).startswith('R'): return 'MB'
    if str(row['vendor_postal_code']).startswith('S'): return 'SK'
    if str(row['vendor_postal_code']).startswith('T'): return 'AB'
    if str(row['vendor_postal_code']).startswith('V'): return 'BC'
    if str(row['vendor_postal_code']).startswith('X'): return 'NT'
    if str(row['vendor_postal_code']).startswith('Y'): return 'YK'
    return 'UNKWN'

contractsData['vendor_province'] = contractsData.apply(prov_from_postal, axis=1)
contractsData['vendor_province'] = contractsData['vendor_province'].astype('category')

def region_from_prov(row):
    if str(row['vendor_province']) in ['NL', 'NS', 'PE', 'NB']: return 'Atlantic'
    if str(row['vendor_province']) in ['YK', 'NT']: return 'Northern'
    if str(row['vendor_province']) in ['QC', 'ON']: return 'Central'
    if str(row['vendor_province']) in ['AB', 'SK', 'MB']: return 'Prairies'
    if str(row['vendor_province']) in ['BC']: return 'Western'
    if str(row['vendor_province']) in ['UNKWN']: return 'Unknown'
    return 'Unknown'

contractsData['vendor_region'] = contractsData.apply(region_from_prov, axis=1)
contractsData['vendor_region'] = contractsData['vendor_region'].astype('category')
contractsData['year'] = contractsData['contract_date'].astype(str).str[0:4]

contractsData = contractsData[(contractsData['original_value'] < contractsData['original_value'].quantile(.90)) &
                                (contractsData['contract_value'] < contractsData['contract_value'].quantile(.90))]

years = contractsData['year'].astype(int).unique().tolist()
years.sort()

external_stylesheets = [dbc.themes.DARKLY]
app = Dash(__name__, external_stylesheets=external_stylesheets)

app.layout = dbc.Container([
    dbc.Row([
        html.H3('Canadian Federal Procurement Contracts Data')
    ]),
    dbc.Row([
        html.P(),
        dbc.Label('Choose Year: '),
        dbc.Select(
            id = 'year-selection',
            options = [{"label": x, "value": x} for x in years],
            value = years[-1]),
        html.P(),
        dbc.Label('Choose Value: '),
        dbc.RadioItems(
            options = [{"label": "Counts", "value": 0},
                       {"label": "Dollars", "value": 1}],
            value=0,
            inline = True,
            id = 'value-selection'
        ),
        html.P()
    ]),
    dbc.Row([
        dbc.Col([
            dcc.Graph(figure={}, id='line')
        ], width=12),
    ]),
    dbc.Row([
        html.P(),
        html.H4('By Commodity Type'),
        html.P()
    ]),
    dbc.Row([
        dbc.Col([
            dcc.Graph(figure={}, id='pie1')
        ], width=4),
        dbc.Col([
            dcc.Graph(figure={}, id='pie2')
        ], width=4),
        dbc.Col([
            dcc.Graph(figure={}, id='pie3')
        ], width=4),
    ]),
    dbc.Row([
        html.P(),
        html.H4('By Solicitation Procedure'),
        html.P(),
        dbc.Checklist(
            options=[{"label": "Grouped", "value": 0}],
            value=[],
            inline = True,
            switch = True,
            id='grouped-selection'
        ),
        html.P()
    ]),
    dbc.Row([
        dbc.Col([
            dcc.Graph(figure={}, id='column')
        ], width=12)
    ]),
], fluid=True)

@callback(
    Output(component_id='line', component_property='figure'),
    [
        Input(component_id='year-selection', component_property='value'),
        Input(component_id='value-selection', component_property='value')
    ]
)
def update_line(year_chosen, value_chosen):
    df = contractsData[contractsData['year'] == str(year_chosen)]

    df['commodity_type'] = df['commodity_type'].astype(str)
    df['vendor_region'] = df['vendor_region'].astype(str)
    df['vendor_province'] = df['vendor_province'].astype(str)
    df['contract_month'] = df['contract_date'].dt.to_period('M').astype(str)
    grouped_df = df.groupby(['contract_month', 'commodity_type']).agg(totalcount=('contract_value', 'count'),
                                                                      totalvalue=('contract_value', 'sum')).reset_index()

    if value_chosen == 0:
        # Create a line plot with Plotly Express
        fig = px.line(grouped_df, x='contract_month', y='totalcount', color='commodity_type', symbol='commodity_type',
                      labels={'contract_month': 'Month', 'totalcount': 'Monthly Total Contracts',
                              'commodity_type': 'Commodity Type'},
                      title='Monthly Contract Counts', markers=True,
                      template='plotly_dark')
    if value_chosen == 1:
        # Create a line plot with Plotly Express
        fig = px.line(grouped_df, x='contract_month', y='totalvalue', color='commodity_type', symbol='commodity_type',
                      labels={'contract_month': 'Month', 'totalvalue': 'Monthly Total Contract Value', 'commodity_type': 'Commodity Type'},
                      title='Monthly Contract Values', markers=True,
                      template='plotly_dark')

    fig.update_xaxes(type='category', categoryorder='category ascending', tickformat="%b-%y")
    fig.update_traces(marker=dict(size=10))
    fig.for_each_trace(lambda trace: trace.update(
        name='Services' if trace.name == 'S' else 'Construction' if trace.name == 'C' else 'Goods'))
    fig.add_annotation(text='Contracts above C$10,000', showarrow=False, xref='paper', x=0, xanchor='left',
                       yref='paper', y=1.05)
    return fig
    #
    # fig = px.histogram(df, x='commodity_type', histfunc='count')
    # return fig

@callback(
    Output(component_id='pie1', component_property='figure'),
    [
        Input(component_id='year-selection', component_property='value'),
        Input(component_id='value-selection', component_property='value')
    ]
)
def update_pie1(year_chosen, value_chosen):
    df = contractsData[contractsData['year'] == str(year_chosen)]
    df = df[df['commodity_type'] == 'G']
    df['vendor_province'] = df['vendor_province'].astype(str)

    if value_chosen==0:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'count')).reset_index()
    if value_chosen==1:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'sum')).reset_index()

    fig = px.pie(data_frame=grouped_df,
                 values='total',
                 names='vendor_province',
                 color_discrete_sequence=px.colors.qualitative.Prism,
                 labels={'vendor_province': 'Province of Vendor', 'totalvalue': 'Annual Total Contract Value'},
                 title = 'Goods',
                 template='plotly_dark')
    # fig.update_traces(textinfo='percent+label', insidetextorientation='radial')
    return fig

@callback(
    Output(component_id='pie2', component_property='figure'),
    [
        Input(component_id='year-selection', component_property='value'),
        Input(component_id='value-selection', component_property='value')
    ]
)
def update_pie2(year_chosen, value_chosen):
    df = contractsData[contractsData['year'] == str(year_chosen)]
    df = df[df['commodity_type'] == 'S']
    df['vendor_province'] = df['vendor_province'].astype(str)

    if value_chosen==0:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'count')).reset_index()
    if value_chosen==1:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'sum')).reset_index()

    fig = px.pie(data_frame=grouped_df,
                 values='total',
                 names='vendor_province',
                 color_discrete_sequence=px.colors.qualitative.Prism,
                 labels={'vendor_province': 'Province of Vendor', 'totalvalue': 'Annual Total Contract Value'},
                 title = 'Services',
                 template='plotly_dark')
    # fig.update_traces(textinfo='percent+label', insidetextorientation='radial')
    return fig

@callback(
    Output(component_id='pie3', component_property='figure'),
    [
        Input(component_id='year-selection', component_property='value'),
        Input(component_id='value-selection', component_property='value')
    ]
)
def update_pie3(year_chosen, value_chosen):
    df = contractsData[contractsData['year'] == str(year_chosen)]
    df = df[df['commodity_type'] == 'C']
    df['vendor_province'] = df['vendor_province'].astype(str)

    if value_chosen==0:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'count')).reset_index()
    if value_chosen==1:
        grouped_df = df.groupby(['vendor_province']).agg(total=('contract_value', 'sum')).reset_index()

    fig = px.pie(data_frame=grouped_df,
                 values='total',
                 names='vendor_province',
                 color_discrete_sequence=px.colors.qualitative.Prism,
                 labels={'vendor_province': 'Province of Vendor', 'totalvalue': 'Annual Total Contract Value'},
                 title = 'Construction',
                 template='plotly_dark')
    # fig.update_traces(textinfo='percent+label', insidetextorientation='radial')
    return fig

@callback(
    Output(component_id='column', component_property='figure'),
    [
        Input(component_id='year-selection', component_property='value'),
        Input(component_id='value-selection', component_property='value'),
        Input(component_id='grouped-selection', component_property='value')
    ]
)
def update_column(year_chosen, value_chosen, groups_chosen):
    df = contractsData[contractsData['year'] == str(year_chosen)]

    # df = contractsData[(contractsData['contract_date'] >= pd.to_datetime('2017-01-01')) & (
    #             contractsData['contract_date'] <= pd.to_datetime('2022-12-31'))]
    df['year'] = df['contract_date'].astype(str).str[0:4]

    if value_chosen == 0:
        df = df.groupby([pd.Grouper(key='solicitation_procedure'),
                         pd.Grouper(key='commodity_type')]
                        )['contract_value'].count().reset_index()
    if value_chosen == 1:
        df = df.groupby([pd.Grouper(key='solicitation_procedure'),
                         pd.Grouper(key='commodity_type')]
                        )['contract_value'].sum().reset_index()
    df['solicitation_procedure'] = df['solicitation_procedure'].astype(str)

    fig = px.bar(data_frame=df,
                 x='commodity_type',
                 y='contract_value',
                 color='solicitation_procedure',
                 text_auto=True,
                 template='plotly_dark',
                 # color_discrete_sequence = px.colors.colorbrewer.Paired,
                 color_discrete_sequence=px.colors.qualitative.Alphabet,
                 labels={'contract_value': 'Annual Total Contract Value in C$', 'commodity_type': 'Commodity Type',
                         'solicitation_procedure': 'Solicitation Procedure'})
    # fig.update_xaxes(dtick="M1", tickformat='%Y', tick0='2017-01-01')
    fig.update_yaxes(tickformat=',.2r')
    newnames = {'UNKWN': 'Unknown', 'AC': 'Advanced Contract Awardd Notice', 'OB': 'Open Bidding', 'TC': 'Traditional',
                'ST': 'Selective Tendering', 'TN': 'Non-competitive'}
    fig.for_each_trace(lambda t: t.update(name=newnames[t.name],
                                          legendgroup=newnames[t.name],
                                          hovertemplate=t.hovertemplate.replace(t.name, newnames[t.name])
                                          )
                       )
    if value_chosen == 0:
        fig.update_layout(yaxis_title = 'Total Contract Numbers')
    if value_chosen == 1:
        fig.update_layout(yaxis_title = 'Total Contract Value in C$')

    if len(groups_chosen) == 0:
        fig.update_layout(barmode='stack')
    else:
        fig.update_layout(barmode='group')
    return fig

    # df = contractsData[contractsData['year'] == str(year_chosen)]
    # df['vendor_province'] = df['vendor_province'].astype(str)
    # df['solicitation_procedure'] = df['solicitation_procedure'].astype(str)
    #
    # if value_chosen==0:
    #     grouped_df = df.groupby([pd.Grouper(key='solicitation_procedure'), pd.Grouper(key='commodity_type')]
    #                 )['contract_value'].count().reset_index()
    # if value_chosen==1:
    #     grouped_df = df.groupby([pd.Grouper(key='solicitation_procedure'), pd.Grouper(key='commodity_type')]
    #                 )['contract_value'].sum().reset_index()
    #
    # fig = px.bar(data_frame = df,
    #               x = 'commodity_type',
    #               y = 'contract_value',
    #               color = 'solicitation_procedure',
    #               text_auto=False,
    #               template='plotly_dark',
    #               barmode = 'stack',
    #               labels={'contract_value': 'Annual Total Contract Value in C$', 'year': 'Calendar Year',
    #                      'solicitation_procedure': 'Solicitation Procedure'},
    #               # color_discrete_sequence = px.colors.colorbrewer.Paired,
    #               color_discrete_sequence = px.colors.qualitative.Alphabet
    #               )
    # # fig.update_xaxes(dtick="M1", tickformat='%Y', tick0='2017-01-01')
    # fig.update_yaxes(tickformat=',.2r')
    # if value_chosen==0:
    #     fig.update_layout(yaxis_title= 'Annual Total Contract Counts')
    # if value_chosen==1:
    #     fig.update_layout(yaxis_title = 'Annual Total Contract Values in C$')
    # # if len(groups_chosen)==1:
    # #     fig.update_layout(barmode='group')
    # # else:
    # #     fig.update_layout(barmode='stack')
    #
    # newnames = {'UNKWN': 'Unknown', 'AC':'Advanced Contract Awardd Notice', 'OB': 'Open Bidding', 'TC': 'Traditional', 'ST': 'Selective Tendering', 'TN': 'Non-competitive'}
    # fig.for_each_trace(lambda t: t.update(name = newnames[t.name],
    #                                       legendgroup = newnames[t.name],
    #                                       hovertemplate = t.hovertemplate.replace(t.name, newnames[t.name])
    #                                      )
    #                   )
    # fig.update_layout(barmode = 'group')
    # # fig.update_layout(barmode = 'stack')
    # return fig

if __name__ == '__main__':
    app.run(debug=True)

